# Storage

The Storage configuration lets you configure via [fsspec](https://filesystem-spec.readthedocs.io/en/latest/)
where `pangeo-forge-runner` puts intermediate & final data products.

## TargetStorage

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.storage.TargetStorage
```

## InputCacheStorage

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.storage.InputCacheStorage
```

## MetadataCacheStorage

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.storage.MetadataCacheStorage
```
